==> acl2_7.1.orig.tar.gz: acl2-7.1/books/centaur/misc/memory-mgmt.lisp <==
; Centaur Miscellaneous Books
; Copyright (C) 2008-2011 Centaur Technology
;
; Contact:
;   Centaur Technology Formal Verification Group
;   7600-C N. Capital of Texas Highway, Suite 300, Austin, TX 78731, USA.
;   http://www.centtech.com/
;
; License: (An MIT/X11-style license)
;
;   Permission is hereby granted, free of charge, to any person obtaining a
;   copy of this software and associated documentation files (the "Software"),
;   to deal in the Software without restriction, including without limitation
;   the rights to use, copy, modify, merge, publish, distribute, sublicense,
;   and/or sell copies of the Software, and to permit persons to whom the
;   Software is furnished to do so, subject to the following conditions:
;
;   The above copyright notice and this permission notice shall be included in
;   all copies or substantial portions of the Software.
;
;   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
;   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
;   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
;   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
;   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
;   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
;   DEALINGS IN THE SOFTWARE.
;
; Original author: Sol Swords <sswords@centtech.com>

(in-package "ACL2")

(include-book "memory-mgmt-logic")
(include-book "tools/include-raw" :dir :system)

;; BOZO eventually rename this to memory-mgmt-raw.lsp, but right now we have
;; a stub that conflicts, so use a different name
; (depends-on "hons-memory-mgmt.lsp")

(defttag memory-mgmt)

; Matt K.: Restricting to Clozure because, for example, hl-hash-table-bytes is
; defined in hons-memory-mgmt.lsp but has "ccl::" without a #+Clozure
; restriction.
#+(and hons Clozure)
(include-raw "hons-memory-mgmt.lsp")

#+(and hons Clozure)
(progn!
 (set-raw-mode t)
 (when (null *hcomp-fn-macro-restore-ht*)
   (start-sol-gc)))

==> acl2_8.5dfsg.orig.tar.gz: acl2-8.5dfsg/books/centaur/misc/memory-mgmt.lisp <==
; Centaur Miscellaneous Books
; Copyright (C) 2008-2011 Centaur Technology
;
; Contact:
;   Centaur Technology Formal Verification Group
;   7600-C N. Capital of Texas Highway, Suite 300, Austin, TX 78731, USA.
;   http://www.centtech.com/
;
; License: (An MIT/X11-style license)
;
;   Permission is hereby granted, free of charge, to any person obtaining a
;   copy of this software and associated documentation files (the "Software"),
;   to deal in the Software without restriction, including without limitation
;   the rights to use, copy, modify, merge, publish, distribute, sublicense,
;   and/or sell copies of the Software, and to permit persons to whom the
;   Software is furnished to do so, subject to the following conditions:
;
;   The above copyright notice and this permission notice shall be included in
;   all copies or substantial portions of the Software.
;
;   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
;   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
;   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
;   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
;   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
;   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
;   DEALINGS IN THE SOFTWARE.
;
; Original author: Sol Swords <sswords@centtech.com>

(in-package "ACL2")

(include-book "memory-mgmt-logic")
(include-book "tools/include-raw" :dir :system)

;; BOZO eventually rename this to memory-mgmt-raw.lsp, but right now we have
;; a stub that conflicts, so use a different name
; (depends-on "hons-memory-mgmt.lsp")

(defttag memory-mgmt)

; Matt K.: Restricting to Clozure because, for example, hl-hash-table-bytes is
; defined in hons-memory-mgmt.lsp but has "ccl::" without a #+Clozure
; restriction.
#+(and hons Clozure)
(include-raw "hons-memory-mgmt.lsp")

(value-triple (set-gc-strategy :delay) :on-skip-proofs t)
